/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha3

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1alpha3 "kubesphere.io/kubesphere/pkg/apis/devops/v1alpha3"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// DevOpsProjectsGetter has a method to return a DevOpsProjectInterface.
// A group's client should implement this interface.
type DevOpsProjectsGetter interface {
	DevOpsProjects() DevOpsProjectInterface
}

// DevOpsProjectInterface has methods to work with DevOpsProject resources.
type DevOpsProjectInterface interface {
	Create(*v1alpha3.DevOpsProject) (*v1alpha3.DevOpsProject, error)
	Update(*v1alpha3.DevOpsProject) (*v1alpha3.DevOpsProject, error)
	UpdateStatus(*v1alpha3.DevOpsProject) (*v1alpha3.DevOpsProject, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha3.DevOpsProject, error)
	List(opts v1.ListOptions) (*v1alpha3.DevOpsProjectList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.DevOpsProject, err error)
	DevOpsProjectExpansion
}

// devOpsProjects implements DevOpsProjectInterface
type devOpsProjects struct {
	client rest.Interface
}

// newDevOpsProjects returns a DevOpsProjects
func newDevOpsProjects(c *DevopsV1alpha3Client) *devOpsProjects {
	return &devOpsProjects{
		client: c.RESTClient(),
	}
}

// Get takes name of the devOpsProject, and returns the corresponding devOpsProject object, and an error if there is any.
func (c *devOpsProjects) Get(name string, options v1.GetOptions) (result *v1alpha3.DevOpsProject, err error) {
	result = &v1alpha3.DevOpsProject{}
	err = c.client.Get().
		Resource("devopsprojects").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of DevOpsProjects that match those selectors.
func (c *devOpsProjects) List(opts v1.ListOptions) (result *v1alpha3.DevOpsProjectList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha3.DevOpsProjectList{}
	err = c.client.Get().
		Resource("devopsprojects").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested devOpsProjects.
func (c *devOpsProjects) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("devopsprojects").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a devOpsProject and creates it.  Returns the server's representation of the devOpsProject, and an error, if there is any.
func (c *devOpsProjects) Create(devOpsProject *v1alpha3.DevOpsProject) (result *v1alpha3.DevOpsProject, err error) {
	result = &v1alpha3.DevOpsProject{}
	err = c.client.Post().
		Resource("devopsprojects").
		Body(devOpsProject).
		Do().
		Into(result)
	return
}

// Update takes the representation of a devOpsProject and updates it. Returns the server's representation of the devOpsProject, and an error, if there is any.
func (c *devOpsProjects) Update(devOpsProject *v1alpha3.DevOpsProject) (result *v1alpha3.DevOpsProject, err error) {
	result = &v1alpha3.DevOpsProject{}
	err = c.client.Put().
		Resource("devopsprojects").
		Name(devOpsProject.Name).
		Body(devOpsProject).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *devOpsProjects) UpdateStatus(devOpsProject *v1alpha3.DevOpsProject) (result *v1alpha3.DevOpsProject, err error) {
	result = &v1alpha3.DevOpsProject{}
	err = c.client.Put().
		Resource("devopsprojects").
		Name(devOpsProject.Name).
		SubResource("status").
		Body(devOpsProject).
		Do().
		Into(result)
	return
}

// Delete takes name of the devOpsProject and deletes it. Returns an error if one occurs.
func (c *devOpsProjects) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("devopsprojects").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *devOpsProjects) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("devopsprojects").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched devOpsProject.
func (c *devOpsProjects) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha3.DevOpsProject, err error) {
	result = &v1alpha3.DevOpsProject{}
	err = c.client.Patch(pt).
		Resource("devopsprojects").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
