/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha2

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1alpha2 "kubesphere.io/kubesphere/pkg/apis/servicemesh/v1alpha2"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// StrategiesGetter has a method to return a StrategyInterface.
// A group's client should implement this interface.
type StrategiesGetter interface {
	Strategies(namespace string) StrategyInterface
}

// StrategyInterface has methods to work with Strategy resources.
type StrategyInterface interface {
	Create(*v1alpha2.Strategy) (*v1alpha2.Strategy, error)
	Update(*v1alpha2.Strategy) (*v1alpha2.Strategy, error)
	UpdateStatus(*v1alpha2.Strategy) (*v1alpha2.Strategy, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha2.Strategy, error)
	List(opts v1.ListOptions) (*v1alpha2.StrategyList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha2.Strategy, err error)
	StrategyExpansion
}

// strategies implements StrategyInterface
type strategies struct {
	client rest.Interface
	ns     string
}

// newStrategies returns a Strategies
func newStrategies(c *ServicemeshV1alpha2Client, namespace string) *strategies {
	return &strategies{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the strategy, and returns the corresponding strategy object, and an error if there is any.
func (c *strategies) Get(name string, options v1.GetOptions) (result *v1alpha2.Strategy, err error) {
	result = &v1alpha2.Strategy{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("strategies").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Strategies that match those selectors.
func (c *strategies) List(opts v1.ListOptions) (result *v1alpha2.StrategyList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha2.StrategyList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("strategies").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested strategies.
func (c *strategies) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("strategies").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a strategy and creates it.  Returns the server's representation of the strategy, and an error, if there is any.
func (c *strategies) Create(strategy *v1alpha2.Strategy) (result *v1alpha2.Strategy, err error) {
	result = &v1alpha2.Strategy{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("strategies").
		Body(strategy).
		Do().
		Into(result)
	return
}

// Update takes the representation of a strategy and updates it. Returns the server's representation of the strategy, and an error, if there is any.
func (c *strategies) Update(strategy *v1alpha2.Strategy) (result *v1alpha2.Strategy, err error) {
	result = &v1alpha2.Strategy{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("strategies").
		Name(strategy.Name).
		Body(strategy).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *strategies) UpdateStatus(strategy *v1alpha2.Strategy) (result *v1alpha2.Strategy, err error) {
	result = &v1alpha2.Strategy{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("strategies").
		Name(strategy.Name).
		SubResource("status").
		Body(strategy).
		Do().
		Into(result)
	return
}

// Delete takes name of the strategy and deletes it. Returns an error if one occurs.
func (c *strategies) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("strategies").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *strategies) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("strategies").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched strategy.
func (c *strategies) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha2.Strategy, err error) {
	result = &v1alpha2.Strategy{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("strategies").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
