/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha2

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1alpha2 "kubesphere.io/kubesphere/pkg/apis/tenant/v1alpha2"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// WorkspaceTemplatesGetter has a method to return a WorkspaceTemplateInterface.
// A group's client should implement this interface.
type WorkspaceTemplatesGetter interface {
	WorkspaceTemplates() WorkspaceTemplateInterface
}

// WorkspaceTemplateInterface has methods to work with WorkspaceTemplate resources.
type WorkspaceTemplateInterface interface {
	Create(*v1alpha2.WorkspaceTemplate) (*v1alpha2.WorkspaceTemplate, error)
	Update(*v1alpha2.WorkspaceTemplate) (*v1alpha2.WorkspaceTemplate, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1alpha2.WorkspaceTemplate, error)
	List(opts v1.ListOptions) (*v1alpha2.WorkspaceTemplateList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha2.WorkspaceTemplate, err error)
	WorkspaceTemplateExpansion
}

// workspaceTemplates implements WorkspaceTemplateInterface
type workspaceTemplates struct {
	client rest.Interface
}

// newWorkspaceTemplates returns a WorkspaceTemplates
func newWorkspaceTemplates(c *TenantV1alpha2Client) *workspaceTemplates {
	return &workspaceTemplates{
		client: c.RESTClient(),
	}
}

// Get takes name of the workspaceTemplate, and returns the corresponding workspaceTemplate object, and an error if there is any.
func (c *workspaceTemplates) Get(name string, options v1.GetOptions) (result *v1alpha2.WorkspaceTemplate, err error) {
	result = &v1alpha2.WorkspaceTemplate{}
	err = c.client.Get().
		Resource("workspacetemplates").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of WorkspaceTemplates that match those selectors.
func (c *workspaceTemplates) List(opts v1.ListOptions) (result *v1alpha2.WorkspaceTemplateList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha2.WorkspaceTemplateList{}
	err = c.client.Get().
		Resource("workspacetemplates").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested workspaceTemplates.
func (c *workspaceTemplates) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("workspacetemplates").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a workspaceTemplate and creates it.  Returns the server's representation of the workspaceTemplate, and an error, if there is any.
func (c *workspaceTemplates) Create(workspaceTemplate *v1alpha2.WorkspaceTemplate) (result *v1alpha2.WorkspaceTemplate, err error) {
	result = &v1alpha2.WorkspaceTemplate{}
	err = c.client.Post().
		Resource("workspacetemplates").
		Body(workspaceTemplate).
		Do().
		Into(result)
	return
}

// Update takes the representation of a workspaceTemplate and updates it. Returns the server's representation of the workspaceTemplate, and an error, if there is any.
func (c *workspaceTemplates) Update(workspaceTemplate *v1alpha2.WorkspaceTemplate) (result *v1alpha2.WorkspaceTemplate, err error) {
	result = &v1alpha2.WorkspaceTemplate{}
	err = c.client.Put().
		Resource("workspacetemplates").
		Name(workspaceTemplate.Name).
		Body(workspaceTemplate).
		Do().
		Into(result)
	return
}

// Delete takes name of the workspaceTemplate and deletes it. Returns an error if one occurs.
func (c *workspaceTemplates) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("workspacetemplates").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *workspaceTemplates) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("workspacetemplates").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched workspaceTemplate.
func (c *workspaceTemplates) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha2.WorkspaceTemplate, err error) {
	result = &v1alpha2.WorkspaceTemplate{}
	err = c.client.Patch(pt).
		Resource("workspacetemplates").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
