/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1beta1 "kubesphere.io/kubesphere/pkg/apis/types/v1beta1"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// FederatedLimitRangesGetter has a method to return a FederatedLimitRangeInterface.
// A group's client should implement this interface.
type FederatedLimitRangesGetter interface {
	FederatedLimitRanges(namespace string) FederatedLimitRangeInterface
}

// FederatedLimitRangeInterface has methods to work with FederatedLimitRange resources.
type FederatedLimitRangeInterface interface {
	Create(*v1beta1.FederatedLimitRange) (*v1beta1.FederatedLimitRange, error)
	Update(*v1beta1.FederatedLimitRange) (*v1beta1.FederatedLimitRange, error)
	UpdateStatus(*v1beta1.FederatedLimitRange) (*v1beta1.FederatedLimitRange, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1beta1.FederatedLimitRange, error)
	List(opts v1.ListOptions) (*v1beta1.FederatedLimitRangeList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedLimitRange, err error)
	FederatedLimitRangeExpansion
}

// federatedLimitRanges implements FederatedLimitRangeInterface
type federatedLimitRanges struct {
	client rest.Interface
	ns     string
}

// newFederatedLimitRanges returns a FederatedLimitRanges
func newFederatedLimitRanges(c *TypesV1beta1Client, namespace string) *federatedLimitRanges {
	return &federatedLimitRanges{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the federatedLimitRange, and returns the corresponding federatedLimitRange object, and an error if there is any.
func (c *federatedLimitRanges) Get(name string, options v1.GetOptions) (result *v1beta1.FederatedLimitRange, err error) {
	result = &v1beta1.FederatedLimitRange{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of FederatedLimitRanges that match those selectors.
func (c *federatedLimitRanges) List(opts v1.ListOptions) (result *v1beta1.FederatedLimitRangeList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.FederatedLimitRangeList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested federatedLimitRanges.
func (c *federatedLimitRanges) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a federatedLimitRange and creates it.  Returns the server's representation of the federatedLimitRange, and an error, if there is any.
func (c *federatedLimitRanges) Create(federatedLimitRange *v1beta1.FederatedLimitRange) (result *v1beta1.FederatedLimitRange, err error) {
	result = &v1beta1.FederatedLimitRange{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		Body(federatedLimitRange).
		Do().
		Into(result)
	return
}

// Update takes the representation of a federatedLimitRange and updates it. Returns the server's representation of the federatedLimitRange, and an error, if there is any.
func (c *federatedLimitRanges) Update(federatedLimitRange *v1beta1.FederatedLimitRange) (result *v1beta1.FederatedLimitRange, err error) {
	result = &v1beta1.FederatedLimitRange{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		Name(federatedLimitRange.Name).
		Body(federatedLimitRange).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *federatedLimitRanges) UpdateStatus(federatedLimitRange *v1beta1.FederatedLimitRange) (result *v1beta1.FederatedLimitRange, err error) {
	result = &v1beta1.FederatedLimitRange{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		Name(federatedLimitRange.Name).
		SubResource("status").
		Body(federatedLimitRange).
		Do().
		Into(result)
	return
}

// Delete takes name of the federatedLimitRange and deletes it. Returns an error if one occurs.
func (c *federatedLimitRanges) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *federatedLimitRanges) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("federatedlimitranges").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched federatedLimitRange.
func (c *federatedLimitRanges) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedLimitRange, err error) {
	result = &v1beta1.FederatedLimitRange{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("federatedlimitranges").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
