/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1beta1 "kubesphere.io/kubesphere/pkg/apis/types/v1beta1"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// FederatedUsersGetter has a method to return a FederatedUserInterface.
// A group's client should implement this interface.
type FederatedUsersGetter interface {
	FederatedUsers(namespace string) FederatedUserInterface
}

// FederatedUserInterface has methods to work with FederatedUser resources.
type FederatedUserInterface interface {
	Create(*v1beta1.FederatedUser) (*v1beta1.FederatedUser, error)
	Update(*v1beta1.FederatedUser) (*v1beta1.FederatedUser, error)
	UpdateStatus(*v1beta1.FederatedUser) (*v1beta1.FederatedUser, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1beta1.FederatedUser, error)
	List(opts v1.ListOptions) (*v1beta1.FederatedUserList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedUser, err error)
	FederatedUserExpansion
}

// federatedUsers implements FederatedUserInterface
type federatedUsers struct {
	client rest.Interface
	ns     string
}

// newFederatedUsers returns a FederatedUsers
func newFederatedUsers(c *TypesV1beta1Client, namespace string) *federatedUsers {
	return &federatedUsers{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the federatedUser, and returns the corresponding federatedUser object, and an error if there is any.
func (c *federatedUsers) Get(name string, options v1.GetOptions) (result *v1beta1.FederatedUser, err error) {
	result = &v1beta1.FederatedUser{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("federatedusers").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of FederatedUsers that match those selectors.
func (c *federatedUsers) List(opts v1.ListOptions) (result *v1beta1.FederatedUserList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.FederatedUserList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("federatedusers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested federatedUsers.
func (c *federatedUsers) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("federatedusers").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a federatedUser and creates it.  Returns the server's representation of the federatedUser, and an error, if there is any.
func (c *federatedUsers) Create(federatedUser *v1beta1.FederatedUser) (result *v1beta1.FederatedUser, err error) {
	result = &v1beta1.FederatedUser{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("federatedusers").
		Body(federatedUser).
		Do().
		Into(result)
	return
}

// Update takes the representation of a federatedUser and updates it. Returns the server's representation of the federatedUser, and an error, if there is any.
func (c *federatedUsers) Update(federatedUser *v1beta1.FederatedUser) (result *v1beta1.FederatedUser, err error) {
	result = &v1beta1.FederatedUser{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("federatedusers").
		Name(federatedUser.Name).
		Body(federatedUser).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *federatedUsers) UpdateStatus(federatedUser *v1beta1.FederatedUser) (result *v1beta1.FederatedUser, err error) {
	result = &v1beta1.FederatedUser{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("federatedusers").
		Name(federatedUser.Name).
		SubResource("status").
		Body(federatedUser).
		Do().
		Into(result)
	return
}

// Delete takes name of the federatedUser and deletes it. Returns an error if one occurs.
func (c *federatedUsers) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("federatedusers").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *federatedUsers) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("federatedusers").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched federatedUser.
func (c *federatedUsers) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedUser, err error) {
	result = &v1beta1.FederatedUser{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("federatedusers").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
