/*
Copyright 2020 The KubeSphere Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
	v1beta1 "kubesphere.io/kubesphere/pkg/apis/types/v1beta1"
	scheme "kubesphere.io/kubesphere/pkg/client/clientset/versioned/scheme"
)

// FederatedWorkspacesGetter has a method to return a FederatedWorkspaceInterface.
// A group's client should implement this interface.
type FederatedWorkspacesGetter interface {
	FederatedWorkspaces() FederatedWorkspaceInterface
}

// FederatedWorkspaceInterface has methods to work with FederatedWorkspace resources.
type FederatedWorkspaceInterface interface {
	Create(*v1beta1.FederatedWorkspace) (*v1beta1.FederatedWorkspace, error)
	Update(*v1beta1.FederatedWorkspace) (*v1beta1.FederatedWorkspace, error)
	UpdateStatus(*v1beta1.FederatedWorkspace) (*v1beta1.FederatedWorkspace, error)
	Delete(name string, options *v1.DeleteOptions) error
	DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
	Get(name string, options v1.GetOptions) (*v1beta1.FederatedWorkspace, error)
	List(opts v1.ListOptions) (*v1beta1.FederatedWorkspaceList, error)
	Watch(opts v1.ListOptions) (watch.Interface, error)
	Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedWorkspace, err error)
	FederatedWorkspaceExpansion
}

// federatedWorkspaces implements FederatedWorkspaceInterface
type federatedWorkspaces struct {
	client rest.Interface
}

// newFederatedWorkspaces returns a FederatedWorkspaces
func newFederatedWorkspaces(c *TypesV1beta1Client) *federatedWorkspaces {
	return &federatedWorkspaces{
		client: c.RESTClient(),
	}
}

// Get takes name of the federatedWorkspace, and returns the corresponding federatedWorkspace object, and an error if there is any.
func (c *federatedWorkspaces) Get(name string, options v1.GetOptions) (result *v1beta1.FederatedWorkspace, err error) {
	result = &v1beta1.FederatedWorkspace{}
	err = c.client.Get().
		Resource("federatedworkspaces").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do().
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of FederatedWorkspaces that match those selectors.
func (c *federatedWorkspaces) List(opts v1.ListOptions) (result *v1beta1.FederatedWorkspaceList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.FederatedWorkspaceList{}
	err = c.client.Get().
		Resource("federatedworkspaces").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do().
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested federatedWorkspaces.
func (c *federatedWorkspaces) Watch(opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Resource("federatedworkspaces").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch()
}

// Create takes the representation of a federatedWorkspace and creates it.  Returns the server's representation of the federatedWorkspace, and an error, if there is any.
func (c *federatedWorkspaces) Create(federatedWorkspace *v1beta1.FederatedWorkspace) (result *v1beta1.FederatedWorkspace, err error) {
	result = &v1beta1.FederatedWorkspace{}
	err = c.client.Post().
		Resource("federatedworkspaces").
		Body(federatedWorkspace).
		Do().
		Into(result)
	return
}

// Update takes the representation of a federatedWorkspace and updates it. Returns the server's representation of the federatedWorkspace, and an error, if there is any.
func (c *federatedWorkspaces) Update(federatedWorkspace *v1beta1.FederatedWorkspace) (result *v1beta1.FederatedWorkspace, err error) {
	result = &v1beta1.FederatedWorkspace{}
	err = c.client.Put().
		Resource("federatedworkspaces").
		Name(federatedWorkspace.Name).
		Body(federatedWorkspace).
		Do().
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (c *federatedWorkspaces) UpdateStatus(federatedWorkspace *v1beta1.FederatedWorkspace) (result *v1beta1.FederatedWorkspace, err error) {
	result = &v1beta1.FederatedWorkspace{}
	err = c.client.Put().
		Resource("federatedworkspaces").
		Name(federatedWorkspace.Name).
		SubResource("status").
		Body(federatedWorkspace).
		Do().
		Into(result)
	return
}

// Delete takes name of the federatedWorkspace and deletes it. Returns an error if one occurs.
func (c *federatedWorkspaces) Delete(name string, options *v1.DeleteOptions) error {
	return c.client.Delete().
		Resource("federatedworkspaces").
		Name(name).
		Body(options).
		Do().
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *federatedWorkspaces) DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error {
	var timeout time.Duration
	if listOptions.TimeoutSeconds != nil {
		timeout = time.Duration(*listOptions.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Resource("federatedworkspaces").
		VersionedParams(&listOptions, scheme.ParameterCodec).
		Timeout(timeout).
		Body(options).
		Do().
		Error()
}

// Patch applies the patch and returns the patched federatedWorkspace.
func (c *federatedWorkspaces) Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.FederatedWorkspace, err error) {
	result = &v1beta1.FederatedWorkspace{}
	err = c.client.Patch(pt).
		Resource("federatedworkspaces").
		SubResource(subresources...).
		Name(name).
		Body(data).
		Do().
		Into(result)
	return
}
